from petisco.base.domain.errors.domain_error import DomainError


class InvalidUuid(DomainError):
    ...
